# -*- mode: makefile; -*-
# -----------------------------------------------------------------------------
#  $RCSfile: Calc.mak.in,v $
# 
#  See Copyright for the status of this software.
# 
#  The OpenSOAP Project
#  http://opensoap.jp/
# -----------------------------------------------------------------------------

# MS SOAP Variables
# SOAPAction HTTP header CalcService Prefix
CALC_SOAPACTION_PREFIX = http://tempuri.org/action/Calc
# MS SOAP Toolkit executable service hostname
MSSOAPSAMPLESERVER = MSSoapSampleServer
#MSSOAPSAMPLESERVER = localhost

SERVICE_NAME = Calc

SAMPLE_MESSAGE_DIR = .
#
console_client_PROGRAMFILES = CalcClient

#
cgi_client_PROGRAMFILES =

#
cgi_service_PROGRAMFILES = CalcService.cgi
#
stdio_service_PROGRAMFILES = CalcService

#
SSML_IN_FILES = ${SERVICE_NAME}.ssml.in
SSML_FILES = ${SSML_IN_FILES:.in=}

WSDL_FILES = CalcService.wsdl
#
RPATH_COPTION = -Wl,-rpath -Wl,
#
prefix = /usr/local/opensoap
exec_prefix = ${prefix}
bindir = ${exec_prefix}/bin
sbindir = ${exec_prefix}/sbin
sysconfdir = ${prefix}/etc
localstatedir = ${prefix}/var
includedir = ${prefix}/include
libdir = ${exec_prefix}/lib

# OpenSOAP conf and data directory
OPENSOAP_SYSCONFDIR = ${prefix}/etc
OPENSOAP_LOCALSTATEDIR = ${prefix}/var
OPENSOAP_SERVICE_LOCALSTATEDIR = ${OPENSOAP_LOCALSTATEDIR}/services
SSML_DIR=${OPENSOAP_SYSCONFDIR}/ssml

#
SERVICE_DIR = ${prefix}/services/${SERVICE_NAME}
#SERVICE_LOCALSTATEDIR = ${OPENSOAP_SERVICE_LOCALSTATEDIR}/${SERVICE_NAME}

#
CGI_BIN_DIR = /home/httpd/cgi-bin

#
INSTALL = /usr/bin/install -c
INSTALL_PROGRAM = ${INSTALL}
INSTALL_DATA = ${INSTALL} -m 644
INSTALL_SCRIPT = ${INSTALL_PROGRAM}

# libiconv
ICONV_LIBS = 
# libxml2 libs
XML2_LIBS = -lxml2
# ssl libs
SSL_LIB_DIR = /usr/local/lib
SSL_LIBS = -L/usr/local/lib -lcrypto
SSL_LDFLAGS = -L${SSL_LIB_DIR} ${RPATH_COPTION}${SSL_LIB_DIR}
SSL_LIBS = 
SSL_LDFLAGS =
#
LIBS = -lpthread -lc 
CC = gcc

#
PROGRAMS = \
	${console_client_PROGRAMFILES} \
	${cgi_client_PROGRAMFILES} \
	${stdio_service_PROGRAMFILES} \
	${cgi_service_PROGRAMFILES}

#
COMMON_LIBS=${XML2_LIBS} ${ICONV_LIBS} ${SSL_LIBS} ${LIBS}

#
# DEBUG_CFLAGS = -g
CFLAGS = ${DEBUG_CFLAGS} -Wall -I${includedir} \
#	-DSERVICE_NAME=\"${SERVICE_NAME}\" \
#	-DSERVICE_DIR=\"${SERVICE_DIR}\" \
#	-DSERVICE_LOCALSTATEDIR=\"${SERVICE_LOCALSTATEDIR}\"
CGI_SERVICE_CFLAGS = ${CFLAGS} -DCONNECT_TYPE=\"cgi\"
#
COMMON_LDFLAGS = -L${libdir} ${RPATH_COPTION}${libdir} ${SSL_LDFLAGS}

#
#SECURITY_LIBS = -lOpenSOAPSecurity
CLIENT_LIBS = ${SECURITY_LIBS} -lOpenSOAPClient
SERVICE_LIBS = -lOpenSOAPService ${CLIENT_LIBS}
CLIENT_LDFLAGS = ${COMMON_LDFLAGS} ${CLIENT_LIBS} ${COMMON_LIBS}
SERVICE_LDFLAGS = ${COMMON_LDFLAGS} ${SERVICE_LIBS} ${COMMON_LIBS}

SOURCES = CalcClient.c CalcService.c
OBJS=${SOURCES:.c=.o} CalcService.cgi.o CalcClient.cgi.o

all: ${PROGRAMS} ${SSML_FILES}

## Make Client Programs

CalcClient: CalcClient.o
	${CC} -o $@ $^ ${CLIENT_LDFLAGS}


## Make Service Programs

CalcService: CalcService.o
	${CC}  -o $@ $^ ${SERVICE_LDFLAGS}

CalcService.cgi: CalcService.cgi.o
	${CC}  -o $@ $^ ${SERVICE_LDFLAGS}

CalcService.cgi.o: CalcService.c
	${CC} ${CGI_SERVICE_CFLAGS} -c -o $@ $<


## Make SSML files
${SSML_FILES}: ${SSML_IN_FILES} Calc.mak
	@for i in ${SSML_IN_FILES}; do \
		s=`echo $$i | sed 's/\.in$$//'`; \
		sed "s%\@servicesdir\@%${prefix}/services%g" > $$s < $$i; \
	done

## Install Programs

#
install-console-client: ${console_client_PROGRAMFILES}
	@mkdir -p ${DESTDIR}${bindir}; \
	for f in $^ ; do \
		echo "$$f install to ${bindir}."; \
		${INSTALL_PROGRAM} \
			$$f ${DESTDIR}${bindir}/$$f; \
	done

#
install-cgi-client-programs: ${cgi_client_PROGRAMFILES}

install-cgi-client-datas:

install-cgi-client: install-cgi-client-programs install-cgi-client-datas

#
install-client: install-console-client install-cgi-client

#
install-common-service-datas: ${WSDL_FILES}
	@mkdir -p ${DESTDIR}${SERVICE_DIR} ; \
	for f in $^ ; do \
		echo "$$f install to ${SERVICE_DIR}."; \
		${INSTALL_PROGRAM} \
			$$f ${DESTDIR}${SERVICE_DIR}; \
	done

#
install-ssml: ${SSML_FILES}
	@mkdir -p ${DESTDIR}${SSML_DIR}; \
	for f in $^ ; do \
		echo "$$f install to ${SSML_DIR}."; \
		${INSTALL_DATA} \
			$$f ${DESTDIR}${SSML_DIR}/$$f; \
	done

install-stdio-service-programs: ${stdio_service_PROGRAMFILES}
	@mkdir -p ${DESTDIR}${SERVICE_DIR}; \
	for f in $^ ; do \
		echo "$$f install to ${SERVICE_DIR}."; \
		${INSTALL_PROGRAM} \
			$$f ${DESTDIR}${SERVICE_DIR}; \
	done

install-stdio-service-datas: install-common-service-datas install-ssml

install-stdio-service: \
	install-stdio-service-programs \
	install-stdio-service-datas

#
install-cgi-service-programs: ${cgi_service_PROGRAMFILES}
	@mkdir -p ${DESTDIR}${CGI_BIN_DIR}; \
	for f in $^ ; do \
		echo "$$f install to ${CGI_BIN_DIR}."; \
		${INSTALL_PROGRAM} \
			$$f ${DESTDIR}${CGI_BIN_DIR}/$$f; \
	done

install-cgi-service-datas: install-common-service-datas

install-cgi-service: install-cgi-service-programs install-cgi-service-datas

install-service: install-cgi-service install-stdio-service

#
install-samples: install-client install-service

## Install Service Programs and cgi client program

install: install-service install-cgi-client

## clean
clean: 
	rm -f ${OBJS} ${PROGRAMS}

## Client test

# use MS Server
ctest1: ${console_client_PROGRAMFILES}
	./CalcClient -s http://${MSSOAPSAMPLESERVER}/MSSoapSamples/Calc/Service/SrSz/AspJsCpp/Calc.asp -a ${CALC_SOAPACTION_PREFIX}.Add 10 + 20

ctest2: ${console_client_PROGRAMFILES}
	./CalcClient -s http://${MSSOAPSAMPLESERVER}/MSSoapSamples/Calc/Service/SrSz/AspJsCpp/Calc.asp -a ${CALC_SOAPACTION_PREFIX}.Subtract 10 - 20

ctest3: ${console_client_PROGRAMFILES}
	./CalcClient -s http://${MSSOAPSAMPLESERVER}/MSSoapSamples/Calc/Service/SrSz/AspJsCpp/Calc.asp -a ${CALC_SOAPACTION_PREFIX}.Multiply 10 x 20

ctest4: ${console_client_PROGRAMFILES}
	./CalcClient -s http://${MSSOAPSAMPLESERVER}/MSSoapSamples/Calc/Service/SrSz/AspJsCpp/Calc.asp -a ${CALC_SOAPACTION_PREFIX}.Devide 10 / 20


ENDPOINT_CGI = http://localhost/cgi-bin/CalcService.cgi
ENDPOINT_SRV = http://localhost/cgi-bin/soapInterface.cgi

# use local CGI service
ctest1o: ${console_client_PROGRAMFILES}
	./CalcClient -s ${ENDPOINT_CGI} 10 + 20

ctest2o: ${console_client_PROGRAMFILES}
	./CalcClient -s ${ENDPOINT_CGI} 10 - 20

ctest3o: ${console_client_PROGRAMFILES}
	./CalcClient -s ${ENDPOINT_CGI} 10 x 20

ctest4o: ${console_client_PROGRAMFILES}
	./CalcClient -s ${ENDPOINT_CGI} 10 / 20

# use local service via OpenSOAP Server
cstest1o: ${console_client_PROGRAMFILES}
	./CalcClient -s ${ENDPOINT_SRV} 10 + 20

cstest2o: ${console_client_PROGRAMFILES}
	./CalcClient -s ${ENDPOINT_SRV} 10 - 20

cstest3o: ${console_client_PROGRAMFILES}
	./CalcClient -s ${ENDPOINT_SRV} 10 x 20

cstest4o: ${console_client_PROGRAMFILES}
	./CalcClient -s ${ENDPOINT_SRV} 10 / 20
