# -*- mode: makefile; -*-
# -----------------------------------------------------------------------------
#  $RCSfile: HelloSec.mak.in,v $
# 
#  See Copyright for the status of this software.
# 
#  The OpenSOAP Project
#  http://opensoap.jp/
# -----------------------------------------------------------------------------

SERVICE_NAME = HelloSec

SAMPLE_MESSAGE_DIR = .
#
console_client_PROGRAMFILES = HelloSecClient

console_client_USEKEYFILES = \
	 	pubKey_HelloService.pem \
		privKey_HelloClient.pem

service_USEKEYFILES = \
	 	privKey_HelloService.pem \
		pubKey_HelloClient.pem

#
cgi_client_PROGRAMFILES =

#
cgi_service_PROGRAMFILES = HelloSecService.cgi
#
stdio_service_PROGRAMFILES = HelloSecService

#
SSML_IN_FILES = ${SERVICE_NAME}.ssml.in
SSML_FILES = ${SSML_IN_FILES:.in=}

#
RPATH_COPTION = -Wl,-rpath -Wl,
#
prefix = /usr/local/opensoap
exec_prefix = ${prefix}
bindir = ${exec_prefix}/bin
sbindir = ${exec_prefix}/sbin
sysconfdir = ${prefix}/etc
localstatedir = ${prefix}/var
includedir = ${prefix}/include
libdir = ${exec_prefix}/lib

# OpenSOAP conf and data directory
OPENSOAP_SYSCONFDIR = ${prefix}/etc
OPENSOAP_LOCALSTATEDIR = ${prefix}/var
OPENSOAP_SERVICE_LOCALSTATEDIR = ${OPENSOAP_LOCALSTATEDIR}/services
SSML_DIR=${OPENSOAP_SYSCONFDIR}/ssml

#
SERVICE_DIR = ${prefix}/services/${SERVICE_NAME}
#SERVICE_LOCALSTATEDIR = ${OPENSOAP_SERVICE_LOCALSTATEDIR}/${SERVICE_NAME}

#
CGI_BIN_DIR = /home/httpd/cgi-bin

#
INSTALL = /usr/bin/install -c
INSTALL_PROGRAM = ${INSTALL}
INSTALL_DATA = ${INSTALL} -m 644
INSTALL_SCRIPT = ${INSTALL_PROGRAM}

# libiconv
ICONV_LIBS = 
# libxml2 libs
XML2_LIBS = -lxml2
# ssl libs
SSL_LIB_DIR = /usr/local/lib
SSL_LIBS = -L/usr/local/lib -lcrypto
SSL_LDFLAGS = -L${SSL_LIB_DIR} ${RPATH_COPTION}${SSL_LIB_DIR}
SSL_LIBS = 
SSL_LDFLAGS =
#
LIBS = -lpthread -lc 
CC = gcc

#
PROGRAMS = \
	${console_client_PROGRAMFILES} \
	${cgi_client_PROGRAMFILES} \
	${stdio_service_PROGRAMFILES} \
	${cgi_service_PROGRAMFILES}

#
COMMON_LIBS=${XML2_LIBS} ${ICONV_LIBS} ${SSL_LIBS} ${LIBS}

#
# DEBUG_CFLAGS = -g
CFLAGS = ${DEBUG_CFLAGS} -Wall -I${includedir} \
	-DSERVICE_DIR=\"${SERVICE_DIR}\"
#	-DSERVICE_NAME=\"${SERVICE_NAME}\" \
#	-DSERVICE_LOCALSTATEDIR=\"${SERVICE_LOCALSTATEDIR}\"
CGI_SERVICE_CFLAGS = ${CFLAGS} -DCONNECT_TYPE=\"cgi\"
#
COMMON_LDFLAGS = -L${libdir} ${RPATH_COPTION}${libdir} ${SSL_LDFLAGS}

#
SECURITY_LIBS = -lOpenSOAPSecurity
CLIENT_LIBS = ${SECURITY_LIBS} -lOpenSOAPClient
SERVICE_LIBS = -lOpenSOAPService ${CLIENT_LIBS}
CLIENT_LDFLAGS = ${COMMON_LDFLAGS} ${CLIENT_LIBS} ${COMMON_LIBS}
SERVICE_LDFLAGS = ${COMMON_LDFLAGS} ${SERVICE_LIBS} ${COMMON_LIBS}

SOURCES = HelloSecClient.c HelloSecService.c
OBJS=${SOURCES:.c=.o} HelloSecService.cgi.o HelloSecClient.cgi.o

all: ${PROGRAMS} ${SSML_FILES}

## Make Client Programs

HelloSecClient: HelloSecClient.o
	${CC} -o $@ $^ ${CLIENT_LDFLAGS}


## Make Service Programs

HelloSecService: HelloSecService.o
	${CC}  -o $@ $^ ${SERVICE_LDFLAGS}

HelloSecService.cgi: HelloSecService.cgi.o
	${CC}  -o $@ $^ ${SERVICE_LDFLAGS}

HelloSecService.cgi.o: HelloSecService.c
	${CC} ${CGI_SERVICE_CFLAGS} -c -o $@ $<


## Make SSML files
${SSML_FILES}: ${SSML_IN_FILES} HelloSec.mak
	for i in ${SSML_IN_FILES} ; do \
		s=`echo $$i | sed 's/\.in$$//'`; \
		sed "s%\@servicesdir\@%${prefix}/services%g" > $$s < $$i; \
	done

## Install Programs

#
install-console-client: ${console_client_PROGRAMFILES}
	@if test -d ${DESTDIR}${bindir}; then \
		echo "${DESTDIR}${bindir} exist."; \
	else \
		echo "${DESTDIR}${bindir} does not exist."; \
		echo "mkdir -p ${DESTDIR}${bindir}."; \
		mkdir -p ${DESTDIR}${bindir}; \
	fi
	@for f in $^ ; do \
		echo "$$f install to ${bindir}."; \
		${INSTALL_PROGRAM} \
			$$f ${DESTDIR}${bindir}/$$f; \
	done

#
install-cgi-client-programs: ${cgi_client_PROGRAMFILES}

install-cgi-client-datas:

install-cgi-client: install-cgi-client-programs install-cgi-client-datas

#
install-client: install-console-client install-cgi-client

#
install-common-service-datas:
	@for d in ${SERVICE_DIR} ${SERVICE_LOCALSTATEDIR} ; do \
		if test -d ${DESTDIR}$$d; then \
			echo "$${d} exist."; \
		else \
			echo "mkdir -p $${d}."; \
			mkdir -p ${DESTDIR}$${d}; \
		fi; \
	done

#
install-ssml: ${SSML_FILES}
	@if test -d ${DESTDIR}${SSML_DIR}; then \
		echo "${DESTDIR}${SSML_DIR} exist."; \
	else \
		echo "mkdir -p ${DESTDIR}${SSML_DIR}."; \
		mkdir -p ${DESTDIR}${SSML_DIR}; \
	fi
	@for f in $^ ; do \
		echo "$$f install to ${SSML_DIR}."; \
		${INSTALL_DATA} \
			$$f ${DESTDIR}${SSML_DIR}/$$f; \
	done

install-stdio-service-programs: ${stdio_service_PROGRAMFILES}
	@if test -d ${DESTDIR}${SERVICE_DIR}; then \
		echo "${DESTDIR}${SERVICE_DIR} exits."; \
	else \
		echo "${DESTDIR}${SERVICE_DIR} does not exit."; \
		echo "mkdir -p ${DESTDIR}${SERVICE_DIR}."; \
		mkdir -p ${DESTDIR}${SERVICE_DIR}; \
	fi
	for f in $^ ; do \
		echo "$$f install to ${SERVICE_DIR}."; \
		${INSTALL_PROGRAM} \
			$$f ${DESTDIR}${SERVICE_DIR}; \
	done

install-stdio-service-datas: install-common-service-datas install-ssml

install-stdio-service: \
	install-stdio-service-programs \
	install-stdio-service-datas

#
install-cgi-service-programs: ${cgi_service_PROGRAMFILES}
	@if test -d ${DESTDIR}${CGI_BIN_DIR}; then \
		echo "${DESTDIR}${CGI_BIN_DIR} exist."; \
	else \
		echo "${DESTDIR}${CGI_BIN_DIR} does not exist."; \
		echo "mkdir -p ${DESTDIR}${CGI_BIN_DIR}."; \
		mkdir -p ${DESTDIR}${CGI_BIN_DIR}; \
	fi
	@for f in $^ ; do \
		echo "$$f install to ${CGI_BIN_DIR}."; \
		${INSTALL_PROGRAM} \
			$$f ${DESTDIR}${CGI_BIN_DIR}/$$f; \
	done

install-cgi-service-datas: install-common-service-datas

install-cgi-service: install-cgi-service-programs install-cgi-service-datas

install-service: install-cgi-service install-stdio-service install-service-usekeys

install-service-usekeys: ${service_USEKEYFILES}
	@if test -d ${DESTDIR}${SERVICE_DIR}; then \
		echo "${DESTDIR}${SERVICE_DIR} exist."; \
	else \
		echo "mkdir -p ${DESTDIR}${SERVICE_DIR}."; \
		mkdir -p ${DESTDIR}${SERVICE_DIR}; \
	fi
	@for f in $^ ; do \
		echo "$$f install to ${SERVICE_DIR}."; \
		${INSTALL_PROGRAM} \
			-m 0644 \
			$$f ${DESTDIR}${SERVICE_DIR}; \
	done

#
install-samples: install-client install-service

## Install Service Programs and cgi client program

install: install-service install-cgi-client



## clean
clean: 
	rm -f ${OBJS} ${PROGRAMS}

## Client test

ctest: ${console_client_PROGRAMFILES}
	./HelloSecClient foo http://localhost/cgi-bin/HelloSecService.cgi

## Service test
stest: ${cgi_service_PROGRAMFILES}
	./HelloSecService.cgi < ${SAMPLE_MESSAGE_DIR}/hello_sec_request.xml
