# -*- mode: makefile; -*-
# -----------------------------------------------------------------------------
#  $RCSfile: SimpleCalc.mak.in,v $
# 
#  See Copyright for the status of this software.
# 
#  The OpenSOAP Project
#  http://opensoap.jp/
# -----------------------------------------------------------------------------

SERVICE_NAME = SimpleCalc

SAMPLE_MESSAGE_DIR = SimpleCalcSampleMessages
#
console_client_PROGRAMFILES = SimpleCalcClient

#
cgi_client_PROGRAMFILES =

#
cgi_service_PROGRAMFILES = SimpleCalcService.cgi
#
stdio_service_PROGRAMFILES = SimpleCalcService

#
SSML_IN_FILES = ${SERVICE_NAME}.ssml.in
SSML_FILES = ${SSML_IN_FILES:.in=}

WSDL_FILES = SimpleCalcService.wsdl
#
RPATH_COPTION = -Wl,-rpath -Wl,
#
prefix = /usr/local/opensoap
exec_prefix = ${prefix}
bindir = ${exec_prefix}/bin
sbindir = ${exec_prefix}/sbin
sysconfdir = ${prefix}/etc
localstatedir = ${prefix}/var
includedir = ${prefix}/include
libdir = ${exec_prefix}/lib

# OpenSOAP conf and data directory
#OPENSOAP_SYSCONFDIR = /var/tmp/OpenSOAP
#OPENSOAP_LOCALSTATEDIR = /var/tmp/OpenSOAP
OPENSOAP_SYSCONFDIR = ${prefix}/etc
OPENSOAP_LOCALSTATEDIR = ${prefix}/var
OPENSOAP_SERVICE_LOCALSTATEDIR = ${OPENSOAP_LOCALSTATEDIR}/services
SSML_DIR=${OPENSOAP_SYSCONFDIR}/ssml

#
SERVICE_DIR = ${prefix}/services/${SERVICE_NAME}
#SERVICE_LOCALSTATEDIR = ${OPENSOAP_SERVICE_LOCALSTATEDIR}/${SERVICE_NAME}

#
CGI_BIN_DIR = /home/httpd/cgi-bin

#
INSTALL = /usr/bin/install -c
INSTALL_PROGRAM = ${INSTALL}
INSTALL_DATA = ${INSTALL} -m 644
INSTALL_SCRIPT = ${INSTALL_PROGRAM}

# libiconv
ICONV_LIBS = 
# libxml2 libs
XML2_LIBS = -lxml2
# ssl libs
SSL_LIB_DIR = /usr/local/lib
SSL_LIBS = -L/usr/local/lib -lcrypto
SSL_LDFLAGS = -L${SSL_LIB_DIR} ${RPATH_COPTION}${SSL_LIB_DIR}
SSL_LIBS = 
SSL_LDFLAGS =
#
LIBS = -lpthread -lc 
CC = gcc

#
PROGRAMS = \
	${console_client_PROGRAMFILES} \
	${cgi_client_PROGRAMFILES} \
	${stdio_service_PROGRAMFILES} \
	${cgi_service_PROGRAMFILES}

#
COMMON_LIBS=${XML2_LIBS} ${ICONV_LIBS} ${SSL_LIBS} ${LIBS}

#
# DEBUG_CFLAGS = -g
CFLAGS = ${DEBUG_CFLAGS} -Wall -I${includedir} \
#	-DSERVICE_NAME=\"${SERVICE_NAME}\" \
#	-DSERVICE_DIR=\"${SERVICE_DIR}\" \
#	-DSERVICE_LOCALSTATEDIR=\"${SERVICE_LOCALSTATEDIR}\"
CGI_SERVICE_CFLAGS = ${CFLAGS} -DCONNECT_TYPE=\"cgi\"
#
COMMON_LDFLAGS = -L${libdir} ${RPATH_COPTION}${libdir} ${SSL_LDFLAGS}

#
#SECURITY_LIBS = -lOpenSOAPSecurity
CLIENT_LIBS = ${SECURITY_LIBS} -lOpenSOAPClient
SERVICE_LIBS = -lOpenSOAPService ${CLIENT_LIBS}
CLIENT_LDFLAGS = ${COMMON_LDFLAGS} ${CLIENT_LIBS} ${COMMON_LIBS}
SERVICE_LDFLAGS = ${COMMON_LDFLAGS} ${SERVICE_LIBS} ${COMMON_LIBS}

SOURCES = SimpleCalcClient.c SimpleCalcService.c
OBJS=${SOURCES:.c=.o} SimpleCalcService.cgi.o SimpleCalcClient.cgi.o

all: ${PROGRAMS} ${SSML_FILES}

## Make Client Programs

SimpleCalcClient: SimpleCalcClient.o
	${CC} -o $@ $^ ${CLIENT_LDFLAGS}


## Make Service Programs

SimpleCalcService: SimpleCalcService.o
	${CC}  -o $@ $^ ${SERVICE_LDFLAGS}

SimpleCalcService.cgi: SimpleCalcService.cgi.o
	${CC}  -o $@ $^ ${SERVICE_LDFLAGS}

SimpleCalcService.cgi.o: SimpleCalcService.c
	${CC} ${CGI_SERVICE_CFLAGS} -c -o $@ $<


## Make SSML files
${SSML_FILES}: ${SSML_IN_FILES} SimpleCalc.mak
	@for i in ${SSML_IN_FILES}; do \
		s=`echo $$i | sed 's/\.in$$//'`; \
		sed "s%\@servicesdir\@%${prefix}/services%g" > $$s < $$i; \
	done


## Install Programs

#
install-console-client: ${console_client_PROGRAMFILES}
	@mkdir -p ${DESTDIR}${bindir}; \
	for f in $^ ; do \
		echo "$$f install to ${bindir}."; \
		${INSTALL_PROGRAM} \
			$$f ${DESTDIR}${bindir}/$$f; \
	done

#
install-cgi-client-programs: ${cgi_client_PROGRAMFILES}

install-cgi-client-datas:

install-cgi-client: install-cgi-client-programs install-cgi-client-datas

#
install-client: install-console-client install-cgi-client

#
install-common-service-datas: ${WSDL_FILES}
	@mkdir -p ${DESTDIR}${SERVICE_DIR} ; \
	for f in $^ ; do \
		echo "$$f install to ${SERVICE_DIR}."; \
		${INSTALL_PROGRAM} \
			$$f ${DESTDIR}${SERVICE_DIR}; \
	done

#
install-ssml: ${SSML_FILES}
	@mkdir -p ${DESTDIR}${SSML_DIR}; \
	for f in $^ ; do \
		echo "$$f install to ${SSML_DIR}."; \
		${INSTALL_DATA} \
			$$f ${DESTDIR}${SSML_DIR}/$$f; \
	done

install-stdio-service-programs: ${stdio_service_PROGRAMFILES}
	@mkdir -p ${DESTDIR}${SERVICE_DIR}; \
	for f in $^ ; do \
		echo "$$f install to ${SERVICE_DIR}."; \
		${INSTALL_PROGRAM} \
			$$f ${DESTDIR}${SERVICE_DIR}; \
	done

install-stdio-service-datas: install-common-service-datas install-ssml

install-stdio-service: \
	install-stdio-service-programs \
	install-stdio-service-datas

#
install-cgi-service-programs: ${cgi_service_PROGRAMFILES}
	@mkdir -p ${DESTDIR}${CGI_BIN_DIR}; \
	for f in $^ ; do \
		echo "$$f install to ${CGI_BIN_DIR}."; \
		${INSTALL_PROGRAM} \
			$$f ${DESTDIR}${CGI_BIN_DIR}/$$f; \
	done

install-cgi-service-datas: install-common-service-datas

install-cgi-service: install-cgi-service-programs install-cgi-service-datas

install-service: install-cgi-service install-stdio-service

#
install-samples: install-client install-service

## Install Service Programs and cgi client program

install: install-service install-cgi-client

## clean objects and programs
clean: 
	rm -f ${OBJS} ${PROGRAMS}


## Test Service Programs

stest1: ${stdio_service_PROGRAMFILES}
	cat ${SAMPLE_MESSAGE_DIR}/add_request.xml | ./SimpleCalcService.cgi
stest2: ${stdio_service_PROGRAMFILES}
	cat ${SAMPLE_MESSAGE_DIR}/subtract_request.xml | ./SimpleCalcService.cgi
stest3: ${stdio_service_PROGRAMFILES}
	cat ${SAMPLE_MESSAGE_DIR}/multiply_request.xml | ./SimpleCalcService.cgi
stest4: ${stdio_service_PROGRAMFILES}
	cat ${SAMPLE_MESSAGE_DIR}/divide_request.xml | ./SimpleCalcService.cgi

## Test Client-Service Hookups

ctest1: ${console_client_PROGRAMFILES}
	./SimpleCalcClient Add 10.0 20.0 http://localhost/cgi-bin/SimpleCalcService.cgi
ctest2: ${console_client_PROGRAMFILES}
	./SimpleCalcClient Subtract 10.0 20.0 http://localhost/cgi-bin/SimpleCalcService.cgi
ctest3: ${console_client_PROGRAMFILES}
	./SimpleCalcClient Multiply 10.0 20.0 http://localhost/cgi-bin/SimpleCalcService.cgi
ctest4: ${console_client_PROGRAMFILES}
	./SimpleCalcClient Divide 10.0 20.0 http://localhost/cgi-bin/SimpleCalcService.cgi

## Test Client-Server-Service Hookups

cstest1: ${console_client_PROGRAMFILES}
	./SimpleCalcClient Add 10.0 20.0 http://localhost/cgi-bin/soapInterface.cgi
cstest2: ${console_client_PROGRAMFILES}
	./SimpleCalcClient Subtract 10.0 20.0 http://localhost/cgi-bin/soapInterface.cgi
cstest3: ${console_client_PROGRAMFILES}
	./SimpleCalcClient Multiply 10.0 20.0 http://localhost/cgi-bin/soapInterface.cgi
cstest4: ${console_client_PROGRAMFILES}
	./SimpleCalcClient Divide 10.0 20.0 http://localhost/cgi-bin/soapInterface.cgi
